@@ -10,7 +10,7 @@ paramwise_cfg = dict(
 # lr = 5e-4 * 128 * 8 / 512 = 0.001
 optimizer = dict(
     type='AdamW',
-    lr=5e-4 * 128 * 8 / 512,
+    lr=5e-4 * 1024 / 512,
     weight_decay=0.05,
     eps=1e-8,
     betas=(0.9, 0.999),
