@@ -1,5 +1,5 @@
 _base_ = [
-    '../_base_/models/mobilenet-v3-small_8xb16_cifar.py',
+    '../_base_/models/mobilenet-v3-small_cifar.py',
     '../_base_/datasets/cifar10_bs16.py',
     '../_base_/schedules/cifar10_bs128.py', '../_base_/default_runtime.py'
 ]
