@@ -1,9 +1,12 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import torch
 import torch.nn.functional as F
 import torch.utils.checkpoint as cp
-from mmcv.cnn import build_activation_layer, build_conv_layer, build_norm_layer
+from mmcv.cnn import (ConvModule, build_activation_layer, build_conv_layer,
+                      build_norm_layer)
 from mmcv.runner import BaseModule, Sequential
 from mmcv.utils.parrots_wrapper import _BatchNorm
+from torch import nn
 
 from ..builder import BACKBONES
 from ..utils.se_layer import SELayer
@@ -229,7 +232,7 @@ class RepVGGBlock(BaseModule):
 
         return fused_weight, fused_bias
 
-    def _norm_to_conv3x3(self, branch_nrom):
+    def _norm_to_conv3x3(self, branch_norm):
         """Convert a norm layer to a conv3x3-bn sequence.
 
         Args:
@@ -241,18 +244,63 @@ class RepVGGBlock(BaseModule):
         """
         input_dim = self.in_channels // self.groups
         conv_weight = torch.zeros((self.in_channels, input_dim, 3, 3),
-                                  dtype=branch_nrom.weight.dtype)
+                                  dtype=branch_norm.weight.dtype)
 
         for i in range(self.in_channels):
             conv_weight[i, i % input_dim, 1, 1] = 1
-        conv_weight = conv_weight.to(branch_nrom.weight.device)
+        conv_weight = conv_weight.to(branch_norm.weight.device)
 
         tmp_conv3x3 = self.create_conv_bn(kernel_size=3)
         tmp_conv3x3.conv.weight.data = conv_weight
-        tmp_conv3x3.norm = branch_nrom
+        tmp_conv3x3.norm = branch_norm
         return tmp_conv3x3
 
 
+class MTSPPF(nn.Module):
+    """MTSPPF block for YOLOX-PAI RepVGG backbone.
+
+    Args:
+        in_channels (int): The input channels of the block.
+        out_channels (int): The output channels of the block.
+        norm_cfg (dict): dictionary to construct and config norm layer.
+            Default: dict(type='BN').
+        act_cfg (dict): Config dict for activation layer.
+            Default: dict(type='ReLU').
+        kernel_size (int): Kernel size of pooling. Default: 5.
+    """
+
+    def __init__(self,
+                 in_channels,
+                 out_channels,
+                 norm_cfg=dict(type='BN'),
+                 act_cfg=dict(type='ReLU'),
+                 kernel_size=5):
+        super().__init__()
+        hidden_features = in_channels // 2  # hidden channels
+        self.conv1 = ConvModule(
+            in_channels,
+            hidden_features,
+            1,
+            stride=1,
+            norm_cfg=norm_cfg,
+            act_cfg=act_cfg)
+        self.conv2 = ConvModule(
+            hidden_features * 4,
+            out_channels,
+            1,
+            stride=1,
+            norm_cfg=norm_cfg,
+            act_cfg=act_cfg)
+        self.maxpool = nn.MaxPool2d(
+            kernel_size=kernel_size, stride=1, padding=kernel_size // 2)
+
+    def forward(self, x):
+        x = self.conv1(x)
+        y1 = self.maxpool(x)
+        y2 = self.maxpool(y1)
+        return self.conv2(torch.cat([x, y1, y2, self.maxpool(y2)], 1))
+
+
 @BACKBONES.register_module()
 class RepVGG(BaseBackbone):
     """RepVGG backbone.
@@ -261,17 +309,24 @@ class RepVGG(BaseBackbone):
     <https://arxiv.org/abs/2101.03697>`_
 
     Args:
-        arch (str | dict): The parameter of RepVGG.
-            If it's a dict, it should contain the following keys:
+        arch (str | dict): RepVGG architecture. If use string,
+            choose from 'A0', 'A1`', 'A2', 'B0', 'B1', 'B1g2', 'B1g4', 'B2'
+            , 'B2g2', 'B2g4', 'B3', 'B3g2', 'B3g4'  or 'D2se'. If use dict,
+             it should have below keys:
 
             - num_blocks (Sequence[int]): Number of blocks in each stage.
             - width_factor (Sequence[float]): Width deflator in each stage.
             - group_layer_map (dict | None): RepVGG Block that declares
               the need to apply group convolution.
-            - se_cfg (dict | None): Se Layer config
+            - se_cfg (dict | None): Se Layer config.
+            - stem_channels (int, optional): The stem channels, the final
+                 stem channels will be
+                 ``min(stem_channels, base_channels*width_factor[0])``.
+                If not set here, 64 is used by default in the code.
+
         in_channels (int): Number of input image channels. Default: 3.
-        base_channels (int): Base channels of RepVGG backbone, work
-            with width_factor together. Default: 64.
+        base_channels (int): Base channels of RepVGG backbone, work with
+            width_factor together. Defaults to 64.
         out_indices (Sequence[int]): Output from which stages. Default: (3, ).
         strides (Sequence[int]): Strides of the first block of each stage.
             Default: (2, 2, 2, 2).
@@ -291,6 +346,7 @@ class RepVGG(BaseBackbone):
         norm_eval (bool): Whether to set norm layers to eval mode, namely,
             freeze running stats (mean and var). Note: Effect on Batch Norm
             and its variants only. Default: False.
+        add_ppf (bool): Whether to use the MTSPPF block. Default: False.
         init_cfg (dict or list[dict], optional): Initialization config dict.
     """
 
@@ -322,7 +378,8 @@ class RepVGG(BaseBackbone):
             num_blocks=[4, 6, 16, 1],
             width_factor=[1, 1, 1, 2.5],
             group_layer_map=None,
-            se_cfg=None),
+            se_cfg=None,
+            stem_channels=64),
         'B1':
         dict(
             num_blocks=[4, 6, 16, 1],
@@ -382,7 +439,14 @@ class RepVGG(BaseBackbone):
             num_blocks=[8, 14, 24, 1],
             width_factor=[2.5, 2.5, 2.5, 5],
             group_layer_map=None,
-            se_cfg=dict(ratio=16, divisor=1))
+            se_cfg=dict(ratio=16, divisor=1)),
+        'yolox-pai-small':
+        dict(
+            num_blocks=[3, 5, 7, 3],
+            width_factor=[1, 1, 1, 1],
+            group_layer_map=None,
+            se_cfg=None,
+            stem_channels=32),
     }
 
     def __init__(self,
@@ -399,6 +463,7 @@ class RepVGG(BaseBackbone):
                  with_cp=False,
                  deploy=False,
                  norm_eval=False,
+                 add_ppf=False,
                  init_cfg=[
                      dict(type='Kaiming', layer=['Conv2d']),
                      dict(
@@ -426,9 +491,9 @@ class RepVGG(BaseBackbone):
         if arch['se_cfg'] is not None:
             assert isinstance(arch['se_cfg'], dict)
 
+        self.base_channels = base_channels
         self.arch = arch
         self.in_channels = in_channels
-        self.base_channels = base_channels
         self.out_indices = out_indices
         self.strides = strides
         self.dilations = dilations
@@ -440,7 +505,12 @@ class RepVGG(BaseBackbone):
         self.with_cp = with_cp
         self.norm_eval = norm_eval
 
-        channels = min(64, int(base_channels * self.arch['width_factor'][0]))
+        # defaults to 64 to prevert BC-breaking if stem_channels
+        # not in arch dict;
+        # the stem channels should not be larger than that of stage1.
+        channels = min(
+            arch.get('stem_channels', 64),
+            int(self.base_channels * self.arch['width_factor'][0]))
         self.stem = RepVGGBlock(
             self.in_channels,
             channels,
@@ -458,7 +528,7 @@ class RepVGG(BaseBackbone):
             num_blocks = self.arch['num_blocks'][i]
             stride = self.strides[i]
             dilation = self.dilations[i]
-            out_channels = int(base_channels * 2**i *
+            out_channels = int(self.base_channels * 2**i *
                                self.arch['width_factor'][i])
 
             stage, next_create_block_idx = self._make_stage(
@@ -470,6 +540,16 @@ class RepVGG(BaseBackbone):
 
             channels = out_channels
 
+        if add_ppf:
+            self.ppf = MTSPPF(
+                out_channels,
+                out_channels,
+                norm_cfg=norm_cfg,
+                act_cfg=act_cfg,
+                kernel_size=5)
+        else:
+            self.ppf = None
+
     def _make_stage(self, in_channels, out_channels, num_blocks, stride,
                     dilation, next_create_block_idx, init_cfg):
         strides = [stride] + [1] * (num_blocks - 1)
@@ -506,6 +586,8 @@ class RepVGG(BaseBackbone):
         for i, stage_name in enumerate(self.stages):
             stage = getattr(self, stage_name)
             x = stage(x)
+            if i + 1 == len(self.stages) and self.ppf is not None:
+                x = self.ppf(x)
             if i in self.out_indices:
                 outs.append(x)
 
