@@ -1,11 +1,12 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-from .attention import MultiheadAttention, ShiftWindowMSA
+from .attention import MultiheadAttention, ShiftWindowMSA, WindowMSAV2
 from .augment.augments import Augments
 from .channel_shuffle import channel_shuffle
 from .embed import (HybridEmbed, PatchEmbed, PatchMerging, resize_pos_embed,
                     resize_relative_position_bias_table)
 from .helpers import is_tracing, to_2tuple, to_3tuple, to_4tuple, to_ntuple
 from .inverted_residual import InvertedResidual
+from .layer_scale import LayerScale
 from .make_divisible import make_divisible
 from .position_encoding import ConditionalPositionEncoding
 from .se_layer import SELayer
@@ -15,5 +16,5 @@ __all__ = [
     'to_ntuple', 'to_2tuple', 'to_3tuple', 'to_4tuple', 'PatchEmbed',
     'PatchMerging', 'HybridEmbed', 'Augments', 'ShiftWindowMSA', 'is_tracing',
     'MultiheadAttention', 'ConditionalPositionEncoding', 'resize_pos_embed',
-    'resize_relative_position_bias_table'
+    'resize_relative_position_bias_table', 'WindowMSAV2', 'LayerScale'
 ]
